package msvar;

import java.io.File;

import com.jstatcom.engine.Engine;
import com.jstatcom.engine.EngineTypes;
import com.jstatcom.engine.PCall;
import com.jstatcom.engine.ox.OxLoadTypes;
import com.jstatcom.io.FileSupport;
import com.jstatcom.model.JSCConstants;
import com.jstatcom.model.JSCData;
import com.jstatcom.model.JSCInt;
import com.jstatcom.model.JSCNArray;
import com.jstatcom.model.JSCSArray;
import com.jstatcom.model.JSCString;
import com.jstatcom.ts.TSDateRange;

/**
 * Holds the MSVAR caller command. Arguments are set via the constructor. They
 * could be set directly or via a symboltable, which holds the arguments under
 * the names defined in <code>MSVARConstants</code>.
 * <p>
 * Results should also be read back and stored under constants defined in
 * <code>MSVARConstants</code> in a global symbol table.
 * 
 * @author <a href="mailto:mk@mk-home.de">Markus Kraetzig </a>
 */
public final class MSVARCall extends PCall {

	private JSCNArray data;
	private JSCSArray namesY;
	private int lags;
	private TSDateRange range;
	private String fName = JSCConstants.getSystemTemp() + "/msvar.out";

	public MSVARCall(JSCNArray y, JSCSArray names, int arLags, TSDateRange range) {
		setName("MSVAR Call");
		// maybe check inputs and copy values here
		this.data = y;
		this.namesY = names;
		this.lags = arLags;
		this.range = range;
	}

	public void runCode() {
		Engine ox = engine();
		ox.load("msvarwrapper", OxLoadTypes.OXO, null);
		ox.load("MSVARWrapper", OxLoadTypes.CLASS, null);
		ox.call("Create", new JSCData[]{
				new JSCInt("freq", range.subPeriodicity()),
				new JSCInt("main_l", range.lowerBound().mainPeriod()),
				new JSCInt("period_l", range.lowerBound().subPeriod()),
				new JSCInt("main_u", range.upperBound().mainPeriod()),
				new JSCInt("period_u", range.upperBound().subPeriod())}, null);
		ox.call("Append", new JSCData[]{data, namesY}, null);
		ox.call("SelectY", new JSCData[]{
				new JSCSArray("aName", namesY.stringAt(0, 0)),
				new JSCInt("startLag", 0), new JSCInt("endLag", lags)}, null);
		ox.call("SetSample", new JSCData[]{
				new JSCInt("main_l", range.lowerBound().mainPeriod()),
				new JSCInt("period_l", range.lowerBound().subPeriod()),
				new JSCInt("main_u", range.upperBound().mainPeriod()),
				new JSCInt("period_u", range.upperBound().subPeriod())}, null);
		ox.call("SetModel", new JSCData[]{new JSCInt("MSM", 5),
				new JSCInt("regimes", 2)}, null);
		ox.call("PrintSetup", new JSCData[]{new JSCInt("width", 120),
				new JSCString("outFile", fName)}, null);
		ox.call("Estimate", null, null);
		ox.call("StdErr", null, null);
		ox.call("PrintStdErr", null, null);
	}

	public void finalCode() {
		// appends output generated in Ox to output buffer
		output.append(FileSupport.readTextFile(fName) + "\n\n");
		new File(fName).delete();
	}

	public Engine engine() {
		return EngineTypes.OX.getEngine();
	}
};
