package msvar;

import java.io.File;

import com.jstatcom.engine.Engine;
import com.jstatcom.engine.EngineTypes;
import com.jstatcom.engine.PCall;
import com.jstatcom.engine.ox.OxLoadTypes;
import com.jstatcom.io.FileSupport;
import com.jstatcom.model.JSCConstants;
import com.jstatcom.model.JSCData;
import com.jstatcom.model.JSCInt;
import com.jstatcom.model.JSCNArray;
import com.jstatcom.model.JSCSArray;
import com.jstatcom.model.JSCString;
import com.jstatcom.model.ModelPanel;
import com.jstatcom.ts.TSDateRange;

/**
 * Specification of MSVAR model.
 * 
 * @author <a href="mailto:mk@mk-home.de">Markus Kraetzig </a>
 */
public class MSVARSpecPanel extends ModelPanel {

	private com.jstatcom.ts.TSSel TSSel = null;
	private javax.swing.JButton jButton = null;
	private com.jstatcom.component.NumSelector numSelector = null;
	private javax.swing.JLabel jLabel = null;

	private com.jstatcom.component.ResultField resultField = null;

	private javax.swing.JPanel jPanel = null;

	/**
	 * This method initializes
	 *  
	 */
	public MSVARSpecPanel() {
		super();
		initialize();
	}

	/**
	 * This method initializes this
	 * 
	 * @return void
	 */
	private void initialize() {
		this.setLayout(new java.awt.BorderLayout());
		this.setSize(550, 503);
		this.add(getTSSel(), java.awt.BorderLayout.EAST);
		this.add(getJPanel(), java.awt.BorderLayout.CENTER);
	}

	/**
	 * 
	 * This method initializes TSSel
	 * 
	 * @return com.jstatcom.ts.TSSel
	 *  
	 */
	private com.jstatcom.ts.TSSel getTSSel() {
		if (TSSel == null) {
			TSSel = new com.jstatcom.ts.TSSel();
			TSSel.setEndogenousDataName("Y_VAR");
			TSSel.setEndogenousStringsName("Y_NAMES");
			TSSel.setExogenousDataName("X_VAR");
			TSSel.setExogenousStringsName("X_NAMES");
			TSSel.setDateRangeName("MSVAR_DRANGE");
			TSSel
					.setCursor(new java.awt.Cursor(
							java.awt.Cursor.DEFAULT_CURSOR));
			TSSel.setOneEndogenousOnly(true);
		}
		return TSSel;
	}

	/**
	 * 
	 * This method initializes jButton
	 * 
	 * @return javax.swing.JButton
	 *  
	 */
	private javax.swing.JButton getJButton() {
		if (jButton == null) {
			jButton = new javax.swing.JButton();
			jButton.setText("Estimate");
			jButton.addActionListener(new java.awt.event.ActionListener() {

				public void actionPerformed(java.awt.event.ActionEvent e) {
					PCall job = new PCall() {

						public void runCode() {
						setName("MSVAR Call");
							JSCConstants.DEBUG = true;
							Engine ox = engine();
							ox.load("msvarwrapper", OxLoadTypes.OXO, null);
							ox.load("MSVARWrapper", OxLoadTypes.CLASS, null);
							ox.call("IsOxPack", new JSCData[]{new JSCInt(
									"false",
									false)}, null);

							TSDateRange range = global().getSymbol(
									"MSVAR_DRANGE").getJSCDRange()
									.getTSDateRange();

							ox.call("Create", new JSCData[]{
									new JSCInt("arg", range.subPeriodicity()),
									new JSCInt("arg", range.lowerBound()
											.mainPeriod()),
									new JSCInt("arg", range.lowerBound()
											.subPeriod()),
									new JSCInt("arg", range.upperBound()
											.mainPeriod()),
									new JSCInt("arg", range.upperBound()
											.subPeriod())}, null);

							JSCNArray data = global().getSymbol("Y_VAR")
									.getJSCNArray();
							JSCSArray namesY = global().getSymbol("Y_NAMES")
									.getJSCSArray();
							ox
									.call("Append",
											new JSCData[]{data, namesY}, null);
							ox.call("Info", null, null);
							// TODO: must be specified for more variables
							ox.call("SelectY", new JSCData[]{
									new JSCSArray("aName", namesY
											.stringAt(0, 0)),
									new JSCInt("s", 0),
									new JSCInt("e", getNumSelector()
											.getIntNumber())}, null);

							ox.call("SetSample", new JSCData[]{
									new JSCInt("arg", range.lowerBound()
											.mainPeriod()),
									new JSCInt("arg", range.lowerBound()
											.subPeriod()),
									new JSCInt("arg", range.upperBound()
											.mainPeriod()),
									new JSCInt("arg", range.upperBound()
											.subPeriod())}, null);

							ox.call("SetModel",
									new JSCData[]{new JSCInt("arg", 5),
											new JSCInt("arg", 2)}, null);

							String fName = JSCConstants.getSystemTemp() + "/"
									+ "msvar.out";

							ox.call("PrintSetup", new JSCData[]{
									new JSCInt("arg", 120),
									new JSCString("outFile", fName)}, null);
							ox.call("Estimate", null, null);
							ox.call("StdErr", null, null);
							ox.call("PrintStdErr", null, null);

							output.append(FileSupport.readTextFile(fName)
									+ "\n\n");
							new File(fName).delete();
							ox.shutdown();
						}

						public Engine engine() {
							return EngineTypes.OX.getEngine();
						}
					};
					job.setName("MSVAR Call");
					job.setOutHolder(getResultField());
					job.execute();

				}
			});

		}
		return jButton;
	}

	/**
	 * 
	 * This method initializes numSelector
	 * 
	 * @return com.jstatcom.component.NumSelector
	 *  
	 */
	private com.jstatcom.component.NumSelector getNumSelector() {
		if (numSelector == null) {
			numSelector = new com.jstatcom.component.NumSelector();
			numSelector.setRangeExpr("[0, 20]");
		}
		return numSelector;
	}

	/**
	 * 
	 * This method initializes jLabel
	 * 
	 * @return javax.swing.JLabel
	 *  
	 */
	private javax.swing.JLabel getJLabel() {
		if (jLabel == null) {
			jLabel = new javax.swing.JLabel();
			jLabel.setText("Endogenous lags");
		}
		return jLabel;
	}

	/**
	 * 
	 * This method initializes resultField
	 * 
	 * @return com.jstatcom.component.ResultField
	 *  
	 */
	private com.jstatcom.component.ResultField getResultField() {
		if (resultField == null) {
			resultField = new com.jstatcom.component.ResultField();
		}
		return resultField;
	}

	/**
	 * 
	 * This method initializes jPanel
	 * 
	 * @return javax.swing.JPanel
	 *  
	 */
	private javax.swing.JPanel getJPanel() {
		if (jPanel == null) {
			jPanel = new javax.swing.JPanel();
			java.awt.GridBagConstraints consGridBagConstraints1 = new java.awt.GridBagConstraints();

			java.awt.GridBagConstraints consGridBagConstraints2 = new java.awt.GridBagConstraints();

			java.awt.GridBagConstraints consGridBagConstraints3 = new java.awt.GridBagConstraints();

			java.awt.GridBagConstraints consGridBagConstraints4 = new java.awt.GridBagConstraints();

			jPanel.setLayout(new java.awt.GridBagLayout());
			consGridBagConstraints1.gridx = 0;
			consGridBagConstraints1.gridy = 2;
			consGridBagConstraints1.gridwidth = 3;
			consGridBagConstraints1.weightx = 1.0;
			consGridBagConstraints1.weighty = 1.0;
			consGridBagConstraints1.fill = java.awt.GridBagConstraints.BOTH;
			consGridBagConstraints1.ipadx = 312;
			consGridBagConstraints1.ipady = 363;
			consGridBagConstraints1.insets = new java.awt.Insets(5, 6, 3, 3);
			consGridBagConstraints2.gridx = 0;
			consGridBagConstraints2.gridy = 0;
			consGridBagConstraints2.weightx = 1.0;
			consGridBagConstraints2.fill = java.awt.GridBagConstraints.HORIZONTAL;
			consGridBagConstraints2.ipadx = 68;
			consGridBagConstraints2.insets = new java.awt.Insets(11, 19, 23, 8);
			consGridBagConstraints3.gridx = 1;
			consGridBagConstraints3.gridy = 0;
			consGridBagConstraints3.insets = new java.awt.Insets(16, 8, 22, 11);
			consGridBagConstraints4.gridx = 2;
			consGridBagConstraints4.gridy = 1;
			consGridBagConstraints4.insets = new java.awt.Insets(22, 12, 4, 16);
			jPanel.add(getResultField(), consGridBagConstraints1);
			jPanel.add(getNumSelector(), consGridBagConstraints2);
			jPanel.add(getJLabel(), consGridBagConstraints3);
			jPanel.add(getJButton(), consGridBagConstraints4);
		}
		return jPanel;
	}

} //  @jve:visual-info decl-index=0 visual-constraint="10,10"
