package msvar;

import java.io.File;

import com.jstatcom.engine.Engine;
import com.jstatcom.engine.EngineTypes;
import com.jstatcom.engine.ox.OxLoadTypes;
import com.jstatcom.model.JSCConstants;
import com.jstatcom.model.JSCData;
import com.jstatcom.model.JSCInt;
import com.jstatcom.model.JSCNArray;
import com.jstatcom.model.JSCSArray;
import com.jstatcom.model.JSCString;
import com.jstatcom.util.UMatrix;

import junit.framework.TestCase;

/**
 * Unittests for the MSVAR frame. Should estimate test models and
 * compare the results with known values.
 * 
 * @author <a href="mailto:mk@mk-home.de">Markus Kraetzig </a>
 */
public class MSVARTests extends TestCase {

	public void testmsVar() {
		JSCConstants.DEBUG = true;
		Engine ox = EngineTypes.OX.getEngine();
		ox.load("msvarwrapper", OxLoadTypes.OXO, null);
		ox.load("MSVARWrapper", OxLoadTypes.CLASS, null);
		ox.call("IsOxPack", new JSCData[]{new JSCInt("false", false)}, null);
		ox.call("Create", new JSCData[]{new JSCInt("arg", 1),
				new JSCInt("arg", 1960), new JSCInt("arg", 1),
				new JSCInt("arg", 2000), new JSCInt("arg", 1)}, null);
		JSCNArray data = new JSCNArray("test", UMatrix.rndu(41, 2));
		ox.call("Append", new JSCData[]{data,
				new JSCSArray("names", new String[]{"a", "b"})}, null);
		ox.call("Info", null, null);

		ox.call("SelectY", new JSCData[]{new JSCString("aName", "a"),
				new JSCInt("s", 0), new JSCInt("e", 1)}, null);
		ox.call("SetSample", new JSCData[]{new JSCInt("arg", 1960),
				new JSCInt("arg", 1), new JSCInt("arg", 2000),
				new JSCInt("arg", 1)}, null);
		ox.call("SetModel", new JSCData[]{new JSCInt("arg", 5),
				new JSCInt("arg", 2)}, null);
		// uses MSM for Hamilton example
		String fName = JSCConstants.getSystemTemp() + "/" + "msvar.out";

		ox.call("PrintSetup", new JSCData[]{new JSCInt("arg", 120),
				new JSCString("outFile", fName)}, null);
		ox.call("Estimate", null, null);
		ox.call("StdErr", null, null);
		ox.call("PrintStdErr", null, null);
		JSCNArray sigma = new JSCNArray("result");
		ox.call("GetSigma", null, new JSCData[]{sigma});

		new File(fName).delete();
		ox.shutdown();
	}
}